@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2015-03-18'; # DATE
-our $VERSION = '0.96'; # VERSION
+our $DATE = '2015-03-19'; # DATE
+our $VERSION = '0.97'; # VERSION
 
 use 5.010001;
 use strict;
@@ -108,6 +108,7 @@ our %copts = (
             my ($go, $val, $r) = @_;
             $r->{format} = $val;
         },
+        default => undef,
     },
     json => {
         getopt  => 'json',
@@ -121,6 +122,7 @@ our %copts = (
     naked_res => {
         getopt  => 'naked-res!',
         summary => 'When outputing as JSON, strip result envelope',
+        'summary.alt.bool.not' => 'When outputing as JSON, add result envelope',
         description => <<'_',
 
 By default, when outputing as JSON, the full enveloped result is returned, e.g.:
@@ -140,6 +142,7 @@ _
             my ($go, $val, $r) = @_;
             $r->{naked_res} = $val ? 1:0;
         },
+        default => 0,
     },
 
     subcommands => {
@@ -1039,7 +1042,12 @@ sub run {
     my ($self) = @_;
     $log->tracef("[pericmd] -> run(), \@ARGV=%s", \@ARGV);
 
-    my $r = {orig_argv=>[@ARGV]};
+    my $co = $self->common_opts;
+
+    my $r = {
+        orig_argv   => [@ARGV],
+        common_opts => $co,
+    };
 
     # completion is special case, we delegate to do_completion()
     if ($self->_detect_completion($r)) {
@@ -1047,6 +1055,10 @@ sub run {
         goto FORMAT;
     }
 
+    # set default from common options
+    $r->{naked_res} = $co->{naked_res}{default} if $co->{naked_res};
+    $r->{format}    = $co->{format}{default} if $co->{format};
+
     if ($self->read_config) {
         # note that we have read the config
         $r->{read_config} = 1;
@@ -1168,7 +1180,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 0.96 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-03-18.
+This document describes version 0.97 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-03-19.
 
 =head1 DESCRIPTION
 
@@ -1308,6 +1320,14 @@ The various values in the C<$r> hash/stash.
 
 =over
 
+=item * orig_argv => array
+
+Original C<@ARGV> at the beginning of C<run()>.
+
+=item * common_opts => hash
+
+Value of C<common_opts> attribute, for convenience.
+
 =item * action => str
 
 Selected action to use. Usually set from the common options.
